@@ -144,14 +144,16 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
                                        "misc-menubar-default", "misc-toolbar-default",
                                        "misc-borders-default", "misc-tab-close-middle-click",
                                        "misc-mouse-autohide", "misc-rewrap-on-resize",
-                                       "misc-copy-on-select", "shortcuts-no-helpkey",
+                                       "misc-copy-on-select", "misc-slim-tabs",
+                                       "shortcuts-no-helpkey",
                                        "shortcuts-no-mnemonics", "shortcuts-no-menukey",
                                        "binding-backspace", "binding-delete",
                                        "binding-ambiguous-width", "background-mode",
                                        "background-image-style", "color-background-vary",
                                        "dropdown-keep-open-default", "dropdown-keep-above",
                                        "dropdown-toggle-focus", "dropdown-status-icon",
-                                       "dropdown-move-to-active", "dropdown-always-show-tabs"
+                                       "dropdown-move-to-active", "dropdown-always-show-tabs",
+                                       "dropdown-show-borders"
                                      };
   const gchar      *props_color[] =  { "color-foreground", "color-cursor",
                                        "color-background", "tab-activity-color",
