@@ -56,6 +56,7 @@ enum
   PROP_DROPDOWN_KEEP_ABOVE,
   PROP_DROPDOWN_ANIMATION_TIME,
   PROP_DROPDOWN_ALWAYS_SHOW_TABS,
+  PROP_DROPDOWN_SHOW_BORDERS,
   N_PROPERTIES
 };
 
@@ -79,11 +80,11 @@ static void     terminal_window_dropdown_status_icon_popup_menu  (GtkStatusIcon
                                                                   TerminalWindowDropdown *dropdown);
 static void     terminal_window_dropdown_hide                    (TerminalWindowDropdown *dropdown);
 static void     terminal_window_dropdown_show                    (TerminalWindowDropdown *dropdown,
-                                                                  guint32                 timestamp);
+                                                                  guint32                 timestamp,
+                                                                  gboolean                activate);
 static void     terminal_window_dropdown_toggle_real             (TerminalWindowDropdown *dropdown,
                                                                   guint32                 timestamp,
                                                                   gboolean                force_show);
-static void     terminal_window_dropdown_update_geometry         (TerminalWindowDropdown *dropdown);
 static void     terminal_dropdown_window_screen_size_changed     (GdkScreen              *screen,
                                                                   TerminalWindowDropdown *dropdown);
 
@@ -202,6 +203,12 @@ terminal_window_dropdown_class_init (TerminalWindowDropdownClass *klass)
                             TRUE,
                             G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
+  dropdown_props[PROP_DROPDOWN_SHOW_BORDERS] =
+      g_param_spec_boolean ("dropdown-show-borders",
+                            NULL, NULL,
+                            FALSE,
+                            G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
+
   /* install all properties */
   g_object_class_install_properties (gobject_class, N_PROPERTIES, dropdown_props);
 }
@@ -219,7 +226,6 @@ terminal_window_dropdown_init (TerminalWindowDropdown *dropdown)
   guint           n;
   const gchar    *name;
   gboolean        keep_open;
-  gboolean        show_borders;
 
   dropdown->rel_width = 0.80;
   dropdown->rel_height = 0.50;
@@ -242,8 +248,6 @@ terminal_window_dropdown_init (TerminalWindowDropdown *dropdown)
 
   /* adjust notebook for drop-down usage */
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (terminal_window_get_notebook (window)), GTK_POS_BOTTOM);
-  g_object_get (terminal_window_get_preferences (window), "misc-borders-default", &show_borders, NULL);
-  gtk_notebook_set_show_border (GTK_NOTEBOOK (terminal_window_get_notebook (window)), show_borders);
   terminal_window_notebook_show_tabs (window);
 
   /* actions we don't want */
@@ -376,13 +380,18 @@ terminal_window_dropdown_set_property (GObject      *object,
       terminal_window_notebook_show_tabs (TERMINAL_WINDOW (dropdown));
       return;
 
+    case PROP_DROPDOWN_SHOW_BORDERS:
+      gtk_notebook_set_show_border (GTK_NOTEBOOK (terminal_window_get_notebook (window)),
+                                    g_value_get_boolean (value));
+      return;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       return;
     }
 
   if (gtk_widget_get_visible (GTK_WIDGET (dropdown)))
-    terminal_window_dropdown_show (dropdown, 0);
+    terminal_window_dropdown_show (dropdown, 0, TRUE);
 }
 
 
@@ -512,7 +521,7 @@ terminal_window_dropdown_status_icon_press_event (GtkStatusIcon          *status
   if (gdk_window_is_visible (gtk_widget_get_window (GTK_WIDGET (dropdown))))
     terminal_window_dropdown_hide (dropdown);
   else
-    terminal_window_dropdown_show (dropdown, event->time);
+    terminal_window_dropdown_show (dropdown, event->time, TRUE);
 
   return TRUE;
 }
@@ -702,7 +711,8 @@ terminal_window_dropdown_hide (TerminalWindowDropdown *dropdown)
 
 static void
 terminal_window_dropdown_show (TerminalWindowDropdown *dropdown,
-                               guint32                 timestamp)
+                               guint32                 timestamp,
+                               gboolean                activate)
 {
   TerminalWindow    *window = TERMINAL_WINDOW (dropdown);
   gint               w, h;
@@ -818,7 +828,8 @@ terminal_window_dropdown_show (TerminalWindowDropdown *dropdown,
     gtk_window_move (GTK_WINDOW (dropdown), x_dest, y_dest);
 
   /* force focus to the window */
-  terminal_util_activate_window (GTK_WINDOW (dropdown));
+  if (activate)
+    terminal_util_activate_window (GTK_WINDOW (dropdown));
 
   if (dropdown->animation_time > 0
       && vbox_h < h)
@@ -870,31 +881,18 @@ terminal_window_dropdown_toggle_real (TerminalWindowDropdown *dropdown,
         }
       else
         {
-          terminal_window_dropdown_show (dropdown, timestamp);
+          terminal_window_dropdown_show (dropdown, timestamp, TRUE);
         }
     }
   else
     {
       /* popup */
-      terminal_window_dropdown_show (dropdown, timestamp);
+      terminal_window_dropdown_show (dropdown, timestamp, TRUE);
     }
 }
 
 
 
-static void
-terminal_window_dropdown_update_geometry (TerminalWindowDropdown *dropdown)
-{
-  terminal_return_if_fail (TERMINAL_IS_WINDOW_DROPDOWN (dropdown));
-
-  /* update geometry if toolbar or menu is shown */
-  if (gtk_widget_get_visible (GTK_WIDGET (dropdown))
-      && dropdown->animation_dir == ANIMATION_DIR_NONE)
-    terminal_window_dropdown_show (dropdown, 0);
-}
-
-
-
 static guint32
 terminal_window_dropdown_get_timestamp (GtkWidget   *widget,
                                         const gchar *startup_id)
@@ -929,7 +927,8 @@ terminal_dropdown_window_screen_size_changed (GdkScreen              *screen,
                                               TerminalWindowDropdown *dropdown)
 {
   /* resize/move terminal window due to a screen size change */
-  terminal_window_dropdown_show (dropdown, 0);
+  if (gtk_widget_get_visible (GTK_WIDGET (dropdown)))
+    terminal_window_dropdown_show (dropdown, 0, FALSE);
 }
 
 
@@ -1056,3 +1055,16 @@ terminal_window_dropdown_get_size (TerminalWindowDropdown *dropdown,
   if (G_LIKELY (grid_height != NULL))
     *grid_height = ((monitor_geo.height * dropdown->rel_height) - ypad) / char_height;
 }
+
+
+
+void
+terminal_window_dropdown_update_geometry (TerminalWindowDropdown *dropdown)
+{
+  terminal_return_if_fail (TERMINAL_IS_WINDOW_DROPDOWN (dropdown));
+
+  /* update geometry if toolbar or menu is shown */
+  if (gtk_widget_get_visible (GTK_WIDGET (dropdown))
+      && dropdown->animation_dir == ANIMATION_DIR_NONE)
+    terminal_window_dropdown_show (dropdown, 0, TRUE);
+}
